@@ -25,7 +25,7 @@ FieldView::FieldView(ReversiGame &reversiGame, QWidget *parent) :
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setFrameStyle(QFrame::NoFrame);
 
-    //connect(scene_, SIGNAL(gameOver()), parent->parentWidget(), SLOT(slotGameOver()));
+    connect(scene_, SIGNAL(playerStep(int,int)), parent, SLOT(slotPlayerStep(int,int)));
 }
 
 QSize FieldView::sizeHint () const
