@@ -12,27 +12,30 @@ ModePanel::ModePanel(QWidget *parent) :
 
     QGridLayout *hlayout = new QGridLayout();
 
-    QLabel *lbMode = new QLabel("Mode: ", this);
+    QLabel *lbMode = new QLabel(tr("Mode: "), this);
     hlayout->addWidget(lbMode, 0, 0);
-    QLabel *lbStrength = new QLabel("AI level: ", this);
+    QLabel *lbStrength = new QLabel(tr("AI level: "), this);
     hlayout->addWidget(lbStrength, 1, 0);
 
     cbMode_ = new QComboBox(this);
-    cbMode_->addItem("Human vs human");
-    cbMode_->addItem("Human vs computer");
-    cbMode_->addItem("Computer vs human");
+    cbMode_->addItem(tr("Human vs human"));
+    cbMode_->addItem(tr("Human vs computer"));
+    cbMode_->addItem(tr("Computer vs human"));
+    cbMode_->addItem(tr("Net (server)"));
+    cbMode_->addItem(tr("Net (client)"));
     cbMode_->setCurrentIndex(1);
     hlayout->addWidget(cbMode_, 0, 1);
 
     cbStrength_ = new QComboBox(this);
-    cbStrength_->addItem("Very easy");
-    cbStrength_->addItem("Easy");
-    cbStrength_->addItem("Medium");
-    cbStrength_->addItem("Hard");
-    cbStrength_->addItem("Very hard");
-    cbStrength_->addItem("Extremely hard");
-    cbStrength_->addItem("Impossible");
-    cbStrength_->setCurrentIndex(2);
+    //cbStrength_->addItem(tr("Very easy"));
+    cbStrength_->addItem(tr("Easy"));
+    cbStrength_->addItem(tr("Medium"));
+    cbStrength_->addItem(tr("Hard"));
+    //cbStrength_->addItem(tr("Very hard"));
+    //cbStrength_->addItem(tr("Extremely hard"));
+    //cbStrength_->addItem(tr("Impossible"));
+    cbStrength_->addItem(tr("Expert"));
+    cbStrength_->setCurrentIndex(1);
     hlayout->addWidget(cbStrength_, 1, 1);
 
     layout->addItem(hlayout);
