@@ -12,12 +12,12 @@ class ReversiItem : public QGraphicsPixmapItem
 {
 public:
     ReversiItem(QGraphicsScene *scene);
-    void setColor(ChipColor c);
+    void setColor(int c);
     int width() const {return pixmap().width();}
     int height() const {return pixmap().height();}
 
 private:
-    QPixmap chipPixmaps_[3];
+    QPixmap chipPixmaps_[13];
 };
 
 #endif // REVERSIITEM_H
